Welcome to ClientVPS Mirrors

Help for package statnetWeb
Title: A Shiny App for Network Modeling with 'statnet'
Version: 0.6.1
Description: A graphical user interface for cross-sectional network modeling with the 'statnet' software suite https://github.com/statnet.
License: GPL-3
Depends: R (≥ 4.0), shiny (≥ 1.8), ergm (≥ 4.6), network (≥ 1.18), lattice, latticeExtra
Imports: DT, sna, RColorBrewer
RoxygenNote: 7.3.2
Encoding: UTF-8
BugReports: https://github.com/statnet/statnetWeb/issues
URL: https://statnet.org, https://github.com/statnet/statnetWeb
NeedsCompilation: no
Packaged: 2025-07-18 18:05:04 UTC; Martina Morris
Author: Martina Morris [cre, aut], Emily Beylerian [aut], Kirk Li [ctb], Samuel Jenness [ctb], Michał Bojanowski ORCID iD [ctb]
Maintainer: Martina Morris <morrism@uw.edu>
Repository: CRAN
Date/Publication: 2025-07-18 18:20:02 UTC

statnetWeb: A graphical user interface for network analysis.

Description

The statnetWeb package makes it easy to run descriptive statistics, graphics and statistical analyses of network data via an intuitive graphical user interface. It is an Rshiny application based on the Statnet suite of network analysis packages See https://statnet.org for more information.

Author(s)

Maintainer: Martina Morris morrism@uw.edu

Authors:

Other contributors:

See Also

Useful links:


Run statnetWeb

Description

Runs the statnetWeb shiny application, a GUI for the statnet suite of network analysis packages.

Usage

run_sw()

Examples

## Not run: 
run_sw()

## End(Not run)


Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.